| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Data.Record.Generic.Rep.Internal
Description
Definition of Rep and functions that do not depend on ".Generic"
Defined as a separate module to avoid circular module dependencies.
Documentation
Representation of some record a
The f parameter describes which functor has been applied to all fields of
the record; in other words Rep I is isomorphic to the record itself.
Basic functions
map' :: (forall x. f x -> g x) -> Rep f a -> Rep g a Source #
Strict map
map' f x is strict in x: if x is undefined, map f x will also be
undefined, even if f never needs any values from x.
Conversion
unsafeFromList :: [b] -> Rep (K b) a Source #
Convert list to Rep
Does not check that the length has the right number of elements.
Utility (for use in .Rep)
compileToHere :: Q [Dec] Source #