| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Data.Record.Internal.Record.Parser
Synopsis
- data RecordInstances = RecordInstances {}
- data Deriving
- parseRecordDef :: Dec -> Q (Maybe (Record (), RecordInstances))
Documentation
data RecordInstances Source #
Constructors
| RecordInstances | |
Fields
| |
Constructors
| DeriveEq | |
| DeriveOrd | |
| DeriveShow |
parseRecordDef :: Dec -> Q (Maybe (Record (), RecordInstances)) Source #
Try to match a record declaration
We use Maybe in these matching functions, along with reportError, so that
we can report multiple errors rather than stopping at the first.